"""
Obserware
Copyright (C) 2021 Akashdeep Dhar

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""


import psutil


def return_mainscreen_threaded_statistics():
    timelist, cputimes, cpuindex = [], psutil.cpu_times(percpu=True), 0
    for indx in cputimes:
        timelist.append(
            (
                cpuindex + 1,
                indx.user,
                indx.nice,
                indx.system,
                indx.idle,
                indx.iowait,
                indx.irq,
                indx.softirq,
                indx.steal,
                indx.guest,
                indx.guest_nice,
            )
        )
        cpuindex += 1
    retndata = {"timelist": timelist, "cpucount": psutil.cpu_count()}
    return retndata
